cd "C:\Shazam\AER"
log using "vc-out-med-BM 2012-18 15Jul2019 Revised", replace
* AER VC CD & TLG LSE & SFA models, common time trend
* Australia & NZ data runs 2012-2018, Ontario data runs 2011-2017
* for NZ include Vector and Wellington separately for full period
* for Ontario include 4 Alectra component DNSPs for 2005-2016 and Alectra in 2017
* Australian DNSP identifiers are 1 ACT, 2 AGD, 3 CIT, 4 END, 5 ENX
* 6 ERG, 7 ESS, 8 JEN, 9 PCR, 10 SAP, 11 AND, 12 TND, 13 UED
version 11
clear
set more off
set maxiter 2000
import excel "DNSPData AusNZOnt 15Jul2019x BM Revised.xls", sheet("DNSP Med") firstrow
summarize
correlate CustNum CircLen RMDemand

generate DNSP=0
replace DNSP=int(EIID/100) if Country==1
replace DNSP=EIID-2000+13 if Country==2
replace DNSP=EIID-3000+32 if Country==3

xtset DNSP Year

* adjust to calendar year
generate yr=Year
replace yr=yr+0.5 if DNSP==3
replace yr=yr+0.5 if DNSP==8
replace yr=yr+0.5 if DNSP==9
replace yr=yr+0.5 if DNSP==11
replace yr=yr+0.5 if DNSP==13
replace yr=yr-0.25 if Country==2
replace yr=yr+0.5 if Country==3

* adjust base to 2012
replace PrOpex=PrOpex/1.242220559 if Country==1
replace PrOpex=PrOpex/1.221665248 if Country==2
replace PrOpex=PrOpex/1.162050691 if Country==3

* adjust for PPPs in 2012
* Australia PPP = 1.527404363
* NZ PPP = 1.482877481
* Canada PPP = 1.249076963
* converting into Australian Dollar base
replace PrOpex=PrOpex*1.482877481/1.527404363 if Country==2
replace PrOpex=PrOpex*1.249076963/1.527404363 if Country==3

generate vc=Opex/PrOpex
generate lvc=log(vc)

generate uc2=vc/CustNum
generate uc3=vc/CircLen
generate uc4=vc/RMDemand
generate obs=DNSP*10+Year-2004
*scatter uc2 obs, saving(uc2)
*scatter uc3 obs, saving(uc3)
*scatter uc4 obs, saving(uc4)

generate ly2=log(CustNum)
generate ly3=log(CircLen)
generate ly4=log(RMDemand)

generate z1=ShareUGC

generate lz1=log(z1)

* delete years prior to 2012 (prior to 2011 for Ontario)
generate yr1=Year
replace yr1=yr1+1.0 if Country==3
drop if yr1 < 2012

* mean correct output data
qui reg ly2
predict mly2
replace ly2=ly2-mly2
qui reg ly3
predict mly3
replace ly3=ly3-mly3
qui reg ly4
predict mly4
replace ly4=ly4-mly4

generate cd2=0
replace cd2=1 if Country==2
generate cd3=0
replace cd3=1 if Country==3

generate ly1=0
generate ly22=ly2*ly2/2
generate ly33=ly3*ly3/2
generate ly44=ly4*ly4/2
generate ly23=ly2*ly3
generate ly24=ly2*ly4
generate ly34=ly3*ly4

* construct dummy variables
qui tabulate DNSP, gen(d)

* models with 3 outputs:

regress lvc ly2-ly4 lz1 yr cd2 cd3
regress lvc ly2-ly4 ly22 ly23 ly24 ly33 ly34 ly44 lz1 yr cd2 cd3

regress lvc ly2-ly4 lz1 yr cd2 cd3 d2-d13
regress lvc ly2-ly4 ly22 ly23 ly24 ly33 ly34 ly44 lz1 yr cd2 cd3 d2-d13

xtpcse lvc ly2-ly4 lz1 yr cd2 cd3 d2-d13, c(a) het
xtpcse lvc ly2-ly4 ly22 ly23 ly24 ly33 ly34 ly44 lz1 yr cd2 cd3 d2-d13, c(a) het

set matsize 1000
mkmat ly1
mkmat ly2
mkmat ly3
mkmat ly4
generate c=1
mkmat c
matrix bh3=e(b)
matlist bh3
matrix e1=c*0
matrix e2=c*bh3[1,1]+ly1*0+ly2*bh3[1,4]+ly3*bh3[1,5]+ly4*bh3[1,6]
matrix e3=c*bh3[1,2]+ly1*0+ly2*bh3[1,5]+ly3*bh3[1,7]+ly4*bh3[1,8]
matrix e4=c*bh3[1,3]+ly1*0+ly2*bh3[1,6]+ly3*bh3[1,8]+ly4*bh3[1,9]
matrix elas = e1, e2, e3, e4
matrix list elas

qui reg lvc ly2-ly4 lz1 yr cd2 cd3
matrix b0 = e(b), .1, ln(e(rmse)^2) , .1
xtfrontier lvc ly2-ly4 lz1 yr cd2 cd3, ti cost from(b0, copy)
predict ci,te
frontier_teci ci
generate ceff=1/ci
generate ceff_l=1/ci_u
generate ceff_u=1/ci_l
list DNSP Year ceff ceff_l ceff_u
summarize DNSP Year ceff ceff_l ceff_u

generate ceffcd=ceff

drop ci ci_u ci_l ceff ceff_l ceff_u

qui reg lvc ly2-ly4 ly22 ly23 ly24 ly33 ly34 ly44 lz1 yr cd2 cd3
matrix b0 = e(b), .1, ln(e(rmse)^2) , .1
xtfrontier lvc ly2-ly4 ly22 ly23 ly24 ly33 ly34 ly44 lz1 yr cd2 cd3, ti cost from(b0, copy)
predict ci,te
frontier_teci ci
generate ceff=1/ci
generate ceff_l=1/ci_u
generate ceff_u=1/ci_l
list DNSP Year ceff ceff_l ceff_u
summarize DNSP Year ceff ceff_l ceff_u

generate cefftl=ceff

drop ci ci_u ci_l ceff ceff_l ceff_u

list DNSP Year ceffcd cefftl
summarize DNSP Year cefftl ceffcd

matrix bh3=e(b)
matlist bh3
matrix e1=c*0
matrix e2=c*bh3[1,1]+ly1*0+ly2*bh3[1,4]+ly3*bh3[1,5]+ly4*bh3[1,6]
matrix e3=c*bh3[1,2]+ly1*0+ly2*bh3[1,5]+ly3*bh3[1,7]+ly4*bh3[1,8]
matrix e4=c*bh3[1,3]+ly1*0+ly2*bh3[1,6]+ly3*bh3[1,8]+ly4*bh3[1,9]
matrix elas = e1, e2, e3, e4
matrix list elas


*xtpcse lvc ly1-ly4 lz1 yr cd2 cd3, c(a) het
*regress lvc ly1-ly4 lz1 yr cd2 cd3
*summarize lvc ly1-ly4 lz1 yr cd2 cd3

*constraint 1 [mu]_cons = 0
*xtfrontier lvc ly1-ly4 lz1 yr cd2 cd3, ti cost constraints(1)

*qui reg lvc ly1-ly4 ly11 ly12 ly13 ly14 ly22 ly23 ly24 ly33 ly34 ly44 lz1 yr cd2 cd3
*matrix b0 = e(b), .1, ln(e(rmse)^2) , .1
*xtfrontier lvc ly1-ly4 ly11 ly12 ly13 ly14 ly22 ly23 ly24 ly33 ly34 ly44 lz1 yr cd2 cd3, ti cost from(b0, copy)


log close
